@@ -27,8 +27,12 @@
 logentry <- function (x, short = NULL, long = NULL, date = NULL, user = NULL){
   chk.hy (x)
   validObject (x)
-
-  .logentry (x, short = short, long = long, date = date, user = user)
+  if (hy.getOption ("log")){
+    warning ("The logbook is deprecated and will soon be removed.")
+    .logentry (x, short = short, long = long, date = date, user = user)
+  } else {
+    x
+  }
 }
 
 ###-------------------------------------------------------------------------------
